@@ -5,12 +5,12 @@
  */
 #include "mockbutton.h"
 
-MockButton::MockButton(KDecoration2::DecorationButtonType type, KDecoration2::Decoration *decoration, QObject *parent)
+MockButton::MockButton(KDecoration3::DecorationButtonType type, KDecoration3::Decoration *decoration, QObject *parent)
     : DecorationButton(type, decoration, parent)
 {
 }
 
-void MockButton::paint(QPainter *painter, const QRect &repaintRegion)
+void MockButton::paint(QPainter *painter, const QRectF &repaintRegion)
 {
     Q_UNUSED(painter)
     Q_UNUSED(repaintRegion)
